Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon CloudWatch Application Insights.

Actions, resources, and condition keys for Amazon CloudWatch Application Insights - Service Authorization Reference

# Actions, resources, and condition keys for Amazon CloudWatch Application Insights

Amazon CloudWatch Application Insights (service prefix: `applicationinsights` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon CloudWatch Application Insights
- Resource types defined by Amazon CloudWatch Application Insights
- Condition keys for Amazon CloudWatch Application Insights

## Actions defined by Amazon CloudWatch Application Insights

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateApplication | Grants permission to create an application from a resource group | Write |  |  |
CreateComponent | Grants permission to create a component from a group of resources | Write |  |  |
CreateLogPattern | Grants permission to create log a pattern | Write |  |  |
DeleteApplication | Grants permission to delete an application | Write |  |  |
DeleteComponent | Grants permission to delete a component | Write |  |  |
DeleteLogPattern | Grants permission to delete a log pattern | Write |  |  |
DescribeApplication | Grants permission to describe an application | Read |  |  |
DescribeComponent | Grants permission to describe a component | Read |  |  |
DescribeComponentConfiguration | Grants permission to describe a component's configuration | Read |  |  |
DescribeComponentConfigurationRecommendation | Grants permission to describe the recommended application component configuration | Read |  |  |
DescribeLogPattern | Grants permission to describe a log pattern | Read |  |  |
DescribeObservation | Grants permission to describe an observation | Read |  |  |
DescribeProblem | Grants permission to describe a problem | Read |  |  |
DescribeProblemObservations | Grants permission to describe the observation in a problem | Read |  |  |
Link [permission only] | Grants permission to share Application Insights resources with a monitoring account | Write |  |  |
ListApplications | Grants permission to list all applications | List |  |  |
ListComponents | Grants permission to list an application's components | List |  |  |
ListConfigurationHistory | Grants permission to list configuration history | List |  |  |
ListLogPatternSets | Grants permission to list log pattern sets for an application | List |  |  |
ListLogPatterns | Grants permission to list log patterns | List |  |  |
ListProblems | Grants permission to list the problems in an application | List |  |  |
ListTagsForResource | Grants permission to list tags for the resource | Read |  |  |
TagResource | Grants permission to tag a resource | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag a resource | Tagging |  | aws:TagKeys |
UpdateApplication | Grants permission to update an application | Write |  |  |
UpdateComponent | Grants permission to update a component | Write |  |  |
UpdateComponentConfiguration | Grants permission to update a component's configuration | Write |  |  |
UpdateLogPattern | Grants permission to update a log pattern | Write |  |  |

## Resource types defined by Amazon CloudWatch Application Insights

Amazon CloudWatch Application Insights does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon CloudWatch Application Insights, specify `"Resource": "*"` in your policy.

## Condition keys for Amazon CloudWatch Application Insights

Amazon CloudWatch Application Insights defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.